@@ -1,6 +1,6 @@
 #######################################################################
-# $Date: 2007-07-05 07:31:01 -0700 (Thu, 05 Jul 2007) $
-# $Revision: 125 $
+# $Date: 2007-07-08 18:53:24 -0700 (Sun, 08 Jul 2007) $
+# $Revision: 132 $
 # $Author: david.romano $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -10,20 +10,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.3.8');
-
-sub base { return shift->{'base'}; }
-
-sub new {
-    my ( $self, %args ) = @_;
-    my $class = ref $self || $self;
-    $self = bless \%args, $class;
-
-    delete $self->{$_} for grep { !/base/xms } keys %{$self};
-    $self->$_ for keys %{$self};
-
-    return $self;
-}
+use version; our $VERSION = qv('0.3.9');
 
 sub get         { return shift->base->call( 'groups.get',        @_ ) }
 sub get_members { return shift->base->call( 'groups.getMembers', @_ ) }
@@ -37,7 +24,7 @@ WWW::Facebook::API::Groups - Facebook Groups
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Groups version 0.3.8
+This document describes WWW::Facebook::API::Groups version 0.3.9
 
 =head1 SYNOPSIS
 
@@ -51,14 +38,6 @@ Methods for accessing groups with L<WWW::Facebook::API>
 
 =over
 
-=item new()
-
-Returns a new instance of this class.
-
-=item base()
-
-The L<WWW::Facebook::API> object to use to make calls to the REST server.
-
 =item get( uids => [ @uids ], gids => [ @gids ] )
 
 The groups.get method of the Facebook API:
