@@ -10,20 +10,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.3.8');
-
-sub base { return shift->{'base'}; }
-
-sub new {
-    my ( $self, %args ) = @_;
-    my $class = ref $self || $self;
-    $self = bless \%args, $class;
-
-    delete $self->{$_} for grep { !/base/xms } keys %{$self};
-    $self->$_ for keys %{$self};
-
-    return $self;
-}
+use version; our $VERSION = qv('0.3.9');
 
 sub set_fbml { return shift->base->call( 'profile.setFBML', @_ ) }
 sub get_fbml { return shift->base->call( 'profile.getFBML', @_ ) }
@@ -41,7 +28,7 @@ WWW::Facebook::API::Profile - Facebook Profile
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Profile version 0.3.8
+This document describes WWW::Facebook::API::Profile version 0.3.9
 
 =head1 SYNOPSIS
 
@@ -55,14 +42,6 @@ Methods for accessing profiles with L<WWW::Facebook::API>
 
 =over
 
-=item new()
-
-Returns a new instance of this class.
-
-=item base()
-
-The L<WWW::Facebook::API> object to use to make calls to the REST server.
-
 =item set_fbml( markup => $fbml_markup, uid => $single_uid )
 
 The profile.setFBML method of the Facebook API.
